@@ -2,6 +2,6 @@
 anorack's private modules
 '''
 
-type(lambda: (yield from []))  # Python >= 3.3 is required
+type(0_0)  # Python >= 3.6 is required
 
 # vim:ts=4 sts=4 sw=4 et
