@@ -1,4 +1,4 @@
-# Copyright © 2016-2020 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2016-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -33,7 +33,7 @@ class Location():
         self.lineno = lineno
 
     def __str__(self):
-        return '{path}:{n}'.format(path=self.file.name, n=self.lineno)
+        return f'{self.file.name}:{self.lineno}'
 
 find_articles = re.compile(
     r'''(?<!\w['’])(?:\b(an?)\s+(?:['‘"“]\s*)?(\d+|[^\W\d_]+)|\b(an?)\s*$)''',
