@@ -1,4 +1,4 @@
-# Copyright © 2016 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2016-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -45,14 +45,14 @@ def init():
     '''
     initialize underlying speech engine
     '''
-    global espeak  # pylint: disable=global-statement
+    global espeak  # pylint: disable=global-statement,global-variable-not-assigned
     from lib import espeak  # pylint: disable=redefined-outer-name,import-outside-toplevel
     espeak.init()
     espeak.set_voice_by_name('en')
     here = os.path.dirname(__file__)
     # Ideally false positives should be fixed in eSpeak,
     # but as a stop-gap measure, we carry data file to correct some of them.
-    path = '{here}/../data/overrides'.format(here=here)
+    path = f'{here}/../data/overrides'
     with open(path, 'rt', encoding='UTF-8') as file:
         for line in file:
             line = line.strip()
