@@ -1,4 +1,4 @@
-# Copyright © 2016-2019 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2016-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -26,14 +26,14 @@ import sys
 import tempfile
 import unittest.mock
 
-from nose.tools import (
+from tests.tools import (
     assert_equal,
     assert_is_instance,
     assert_not_equal,
+    isolation,
+    testcase,
 )
 
-from tests.tools import isolation
-
 @contextlib.contextmanager
 def tmpcwd():
     with tempfile.TemporaryDirectory(prefix='anorack.tests.') as tmpdir:
@@ -112,6 +112,7 @@ def t(*, stdin=None, files=None, stdout, stdout_ipa=None, stderr='', stderr_ipa=
     assert_equal(stderr_ipa, actual.stderr)
     assert_equal(actual.rc, 0)
 
+@testcase
 def test_stdin():
     t(
         stdin=(
@@ -129,6 +130,7 @@ def test_stdin():
         ),
     )
 
+@testcase
 @tmpcwd()
 def test_files():
     t(
@@ -146,6 +148,7 @@ def test_files():
         ),
     )
 
+@testcase
 def test_warning():
     def dummy_choose_art(phon):  # pylint: disable=unused-argument
         return NotImplemented
@@ -157,15 +160,13 @@ def test_warning():
             stderr_ipa="anorack: warning: can't determine correct article for 'scratch' /skɹˈatʃ/\n",
         )
 
+@testcase
 def test_bad_io():
     argv = ['anorack', '/nonexistent', '-']
     actual = run_main(argv, 'a African')
     assert_equal('<stdin>:', actual.stdout[:8])
-    stderr = '{prog}: {path}: {err}\n'.format(
-        prog=argv[0],
-        path=argv[1],
-        err=os.strerror(errno.ENOENT)
-    )
+    err = os.strerror(errno.ENOENT)
+    stderr = f'{argv[0]}: {argv[1]}: {err}\n'
     assert_equal(stderr, actual.stderr)
     assert_equal(actual.rc, 1)
     argv[1:1] = ['--traceback']
@@ -175,6 +176,7 @@ def test_bad_io():
     assert_is_instance(actual.rc, OSError)
     assert_equal(actual.rc.errno, errno.ENOENT)
 
+@testcase
 def test_changelog():
     argv = ['anorack', 'doc/changelog']
     actual = run_main(argv, None)
@@ -182,6 +184,7 @@ def test_changelog():
     assert_equal('', actual.stderr)
     assert_equal(actual.rc, 0)
 
+@testcase
 def test_version():
     argv = ['anorack', '--version']
     actual = run_main(argv, None)
@@ -189,4 +192,6 @@ def test_version():
     assert_equal('', actual.stderr)
     assert_equal(actual.rc, 0)
 
+del testcase
+
 # vim:ts=4 sts=4 sw=4 et
