@@ -1,4 +1,4 @@
-# Copyright © 2016-2018 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2016-2021 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -21,12 +21,14 @@
 import io
 import unittest.mock
 
-from nose.tools import (
+from tests.tools import (
     assert_equal,
+    testcase,
 )
 
 import lib.misc as M
 
+@testcase
 def test_warn():
     stderr = io.StringIO()
     with unittest.mock.patch('sys.stderr', stderr):
@@ -37,4 +39,6 @@ def test_warn():
         'anorack: warning: NOBODY expects the Spanish Inquisition!\n'
     )
 
+del testcase
+
 # vim:ts=4 sts=4 sw=4 et
