@@ -1,4 +1,4 @@
-# Copyright © 2016 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2016-2022 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -21,6 +21,7 @@
 import concurrent.futures
 import functools
 import sys
+import unittest
 
 def isolation(f):
     if 'coverage' in sys.modules:
@@ -35,6 +36,40 @@ def isolation(f):
                 return ftr.result()
     return wrapper
 
-__all__ = ['isolation']
+def testcase(f):
+    class TestCase(unittest.TestCase):  # pylint: disable=redefined-outer-name
+        @staticmethod
+        def test():
+            return f()
+        def __str__(self):
+            return f'{f.__module__}.{f.__name__}'
+    return TestCase
+
+tc = unittest.TestCase('__hash__')
+
+assert_equal = tc.assertEqual
+assert_is = tc.assertIs
+assert_is_instance = tc.assertIsInstance
+assert_not_equal = tc.assertNotEqual
+
+del tc
+
+class TestCase(unittest.TestCase):
+    def __str__(self):
+        return '{cls}.{name}'.format(
+            cls=unittest.util.strclass(self.__class__),
+            name=self._testMethodName,
+        )
+
+__all__ = [
+    'isolation',
+    'testcase',
+    'TestCase',
+    # nose-compatible:
+    'assert_equal',
+    'assert_is',
+    'assert_is_instance',
+    'assert_not_equal',
+]
 
 # vim:ts=4 sts=4 sw=4 et
